@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) 2014-2019 The mqttwarn developers
+# (c) 2014-2021 The mqttwarn developers
 import os
 import sys
 import ast
@@ -35,6 +35,8 @@ class Config(RawConfigParser):
         self.read_file(f)
         f.close()
 
+        self.configuration_path = os.path.dirname(configuration_file)
+
         ''' set defaults '''
         self.hostname     = 'localhost'
         self.port         = 1883
@@ -53,7 +55,6 @@ class Config(RawConfigParser):
         self.functions    = None
         self.num_workers  = 1
 
-        self.directory    = '.'
         self.ca_certs     = None
         self.tls_version  = None
         self.certfile     = None
@@ -82,7 +83,20 @@ class Config(RawConfigParser):
                 self.tls_version = ssl.PROTOCOL_SSLv3
 
         self.loglevelnumber = self.level2number(self.loglevel)
-        self.functions = load_functions(self.functions)
+
+        # Load function file as given (backward-compatibility).
+        if os.path.isfile(self.functions):
+            functions_file = self.functions
+
+        # Load function file as given if path is absolute.
+        elif os.path.isabs(self.functions):
+            functions_file = self.functions
+
+        # Load function file relative to path of configuration file if path is relative.
+        else:
+            functions_file = os.path.join(self.configuration_path, self.functions)
+
+        self.functions = load_functions(functions_file)
 
 
     def level2number(self, level):
